      SUBROUTINE ERM0
C      PRINT *,'PROGRAM FAILS IN SETUP'
      STOP
      RETURN
      END
